@@ -1,5 +1,5 @@
 /* mknod -- make special files
-   Copyright (C) 90, 91, 1995-2004 Free Software Foundation, Inc.
+   Copyright (C) 90, 91, 1995-2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by David MacKenzie <djm@ai.mit.edu>  */
 
@@ -88,7 +88,6 @@ int
 main (int argc, char **argv)
 {
   mode_t newmode;
-  struct mode_change *change;
   const char *specified_mode;
   int optc;
   int expected_operands;
@@ -121,13 +120,11 @@ main (int argc, char **argv)
   newmode = (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);
   if (specified_mode)
     {
-      newmode &= ~ umask (0);
-      change = mode_compile (specified_mode, 0);
-      if (change == MODE_INVALID)
+      struct mode_change *change = mode_compile (specified_mode);
+      if (!change)
 	error (EXIT_FAILURE, 0, _("invalid mode"));
-      else if (change == MODE_MEMORY_EXHAUSTED)
-	xalloc_die ();
-      newmode = mode_adjust (newmode, change);
+      newmode = mode_adjust (newmode, change, umask (0));
+      free (change);
     }
 
   /* If the number of arguments is 0 or 1,
